@@ -1,4 +1,4 @@
-# $Id: Atom.pm,v 1.2 2003/09/08 03:38:48 btrott Exp $
+# $Id: Atom.pm,v 1.3 2003/09/08 07:25:57 btrott Exp $
 
 package XML::Atom;
 use strict;
@@ -6,13 +6,31 @@ use strict;
 use base qw( XML::Atom::ErrorHandler );
 
 use vars qw( $VERSION );
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 ## Methods to:
 ##     - set defaults (encoding, language?)
 ##     - set up modules/namespaces (add_module)
 ##     - syntactic sugar (new_feed, new_entry, etc)
 
+package XML::Atom::Namespace;
+use strict;
+
+sub new {
+    my $class = shift;
+    my($prefix, $uri) = @_;
+    bless { prefix => $prefix, uri => $uri }, $class;
+}
+
+sub DESTROY { }
+
+use vars qw( $AUTOLOAD );
+sub AUTOLOAD {
+    (my $var = $AUTOLOAD) =~ s!.+::!!;
+    no strict 'refs';
+    ($_[0], $var);
+}
+
 1;
 __END__
 
